Struct Mode
pub struct Mode(/* private fields */);Implementations
impl Mode
impl Mode
pub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u16) -> Option<Mode>
pub const fn from_bits(bits: u16) -> Option<Mode>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u16) -> Mode
pub const fn from_bits_truncate(bits: u16) -> Mode
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u16) -> Mode
pub const fn from_bits_retain(bits: u16) -> Mode
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Mode>
pub fn from_name(name: &str) -> Option<Mode>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Mode) -> bool
pub const fn intersects(&self, other: Mode) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Mode) -> bool
pub const fn contains(&self, other: Mode) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Mode)
pub fn remove(&mut self, other: Mode)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: Mode, value: bool)
pub fn set(&mut self, other: Mode, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Mode) -> Mode
pub const fn intersection(self, other: Mode) -> Mode
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: Mode) -> Mode
pub const fn difference(self, other: Mode) -> Mode
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Mode) -> Mode
pub const fn symmetric_difference(self, other: Mode) -> Mode
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Mode
pub const fn complement(self) -> Mode
The bitwise negation (!) of the bits in self, truncating the result.
impl Mode
impl Mode
pub const fn iter(&self) -> Iter<Mode>
pub const fn iter(&self) -> Iter<Mode>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Mode>
pub const fn iter_names(&self) -> IterNames<Mode>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
impl Mode
impl Mode
pub const fn from_raw_mode(st_mode: u16) -> Mode
Available on non-ESP-IDF only.
pub const fn from_raw_mode(st_mode: u16) -> Mode
Construct a Mode from the mode bits of the st_mode field of a
Mode.
pub const fn as_raw_mode(self) -> u16
Available on non-ESP-IDF only.
pub const fn as_raw_mode(self) -> u16
Construct an st_mode value from a Mode.