Struct OFlags
pub struct OFlags(/* private fields */);Expand description
O_* constants for use with openat.
Implementations
impl OFlags
impl OFlags
pub const RWMODE: OFlags
pub const RWMODE: OFlags
Similar to ACCMODE, but just includes the read/write flags, and
no other flags.
On some platforms, PATH may be included in ACCMODE, when
sometimes we really just want the read/write bits. Caution is
indicated, as the presence of PATH may mean that the read/write
bits don’t have their usual meaning.
pub const DSYNC: OFlags
Available on neither DragonFly BSD nor ESP-IDF nor Horizon nor L4Re nor Redox OS nor Play Station Vita.
pub const DSYNC: OFlags
O_DSYNC
impl OFlags
impl OFlags
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<OFlags>
pub const fn from_bits(bits: u32) -> Option<OFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> OFlags
pub const fn from_bits_truncate(bits: u32) -> OFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> OFlags
pub const fn from_bits_retain(bits: u32) -> OFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<OFlags>
pub fn from_name(name: &str) -> Option<OFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: OFlags) -> bool
pub const fn intersects(&self, other: OFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: OFlags) -> bool
pub const fn contains(&self, other: OFlags) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: OFlags)
pub fn remove(&mut self, other: OFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: OFlags, value: bool)
pub fn set(&mut self, other: OFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: OFlags) -> OFlags
pub const fn intersection(self, other: OFlags) -> OFlags
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: OFlags) -> OFlags
pub const fn difference(self, other: OFlags) -> OFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: OFlags) -> OFlags
pub const fn symmetric_difference(self, other: OFlags) -> OFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> OFlags
pub const fn complement(self) -> OFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl OFlags
impl OFlags
pub const fn iter(&self) -> Iter<OFlags>
pub const fn iter(&self) -> Iter<OFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<OFlags>
pub const fn iter_names(&self) -> IterNames<OFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.